@@ -1,5 +1,7 @@
 import requests
 from urllib.parse import urlencode
+from .log import logger
+
 
 class RestAPI:
 
@@ -13,6 +15,7 @@ class RestAPI:
         }
 
     def _return_result(self, r):
+        logger.info(f"HTTP status code {r.status_code}")
         result = {
             'status_code': r.status_code,
         }
@@ -31,6 +34,8 @@ class RestAPI:
         for k, v in payload.items():
             if v is not None:
                 data[k] = v
+
+        logger.info(f"HTTP payload: {data}")
         return data
 
     def get_resources(self, resource, payload=None, resource_id=None):
@@ -48,6 +53,8 @@ class RestAPI:
 
             query_url = query_url + '?' + data
 
+        logger.info(f"HTTP GET to {query_url}")
+
         r = requests.get(query_url, headers=self.headers, timeout=self.timeout)
         return self._return_result(r)
 
@@ -55,22 +62,24 @@ class RestAPI:
         data = self._handle_payload(payload)
         query_url = self.endpoint + '/' + resource
 
-
         if not resource_id:
+            logger.info(f"HTTP POST to {query_url}")
             r = requests.post(query_url, json=data, headers=self.headers, timeout=self.timeout)
             return self._return_result(r)
 
-
         query_url += '/' + resource_id
         if action:
             query_url += '/' + action
+            logger.info(f"HTTP POST to {query_url}")
             r = requests.post(query_url, json=data, headers=self.headers, timeout=self.timeout)
             return self._return_result(r)
         else:
+            logger.info(f"HTTP PATCH to {query_url}")
             r = requests.patch(query_url, json=data, headers=self.headers, timeout=self.timeout)
             return self._return_result(r)
 
     def delete_resource(self, resource, resource_id):
         query_url = self.endpoint + '/' + resource + '/' + resource_id
+        logger.info(f"HTTP DELETE to {query_url}")
         r = requests.delete(query_url, headers=self.headers, timeout=self.timeout)
         return self._return_result(r)
