@@ -1,29 +1,22 @@
 import click
-from . import _init, _list, _show, _create, _update, _delete
-
-headers = ['name', 'created_at', 'zone', 'tags', 'uuid']
 
 @click.group()
-@click.option('--api-token', '-a', envvar='CLOUDSCALE_API_TOKEN', help="API token.")
-@click.option('--profile', '-p', help="Profile used in config file.")
-@click.option('--verbose', '-v', is_flag=True, help='Enables verbose mode.')
 @click.pass_context
-def network(ctx, profile, api_token, verbose):
-    _init(
-        ctx=ctx,
-        api_token=api_token,
-        profile=profile,
-        verbose=verbose,
-    )
+def network(ctx):
+    ctx.obj.cloud_resource_name = "network"
+    ctx.obj.headers = [
+        'name',
+        'created_at',
+        'zone',
+        'tags',
+        'uuid',
+    ]
 
 @click.option('--filter-tag')
 @network.command("list")
 @click.pass_obj
 def cmd_list(cloudscale, filter_tag):
-    resource = cloudscale.network
-    _list(
-        resource=resource,
-        headers=headers,
+    cloudscale.cmd_list(
         filter_tag=filter_tag,
     )
 
@@ -31,9 +24,7 @@ def cmd_list(cloudscale, filter_tag):
 @network.command("show")
 @click.pass_obj
 def cmd_show(cloudscale, uuid):
-    resource = cloudscale.network
-    _show(
-        resource=resource,
+    cloudscale.cmd_show(
         uuid=uuid,
     )
 
@@ -45,15 +36,13 @@ def cmd_show(cloudscale, uuid):
 @network.command("create")
 @click.pass_obj
 def cmd_create(cloudscale, name, zone, mtu, auto_create_ipv4_subnet, tags):
-    resource = cloudscale.network
-    _create(
-        resource=resource,
+    cloudscale.cmd_create(
         name=name,
         zone=zone,
         mtu=mtu,
         auto_create_ipv4_subnet=auto_create_ipv4_subnet,
         tags=tags,
-        )
+    )
 
 @click.argument('uuid', required=True)
 @click.option('--name')
@@ -64,9 +53,7 @@ def cmd_create(cloudscale, name, zone, mtu, auto_create_ipv4_subnet, tags):
 @network.command("update")
 @click.pass_obj
 def cmd_update(cloudscale, uuid, name, mtu, tags, clear_tags, clear_all_tags):
-    resource = cloudscale.network
-    _update(
-        resource=resource,
+    cloudscale.cmd_update(
         uuid=uuid,
         tags=tags,
         clear_tags=clear_tags,
@@ -80,10 +67,7 @@ def cmd_update(cloudscale, uuid, name, mtu, tags, clear_tags, clear_all_tags):
 @network.command("delete")
 @click.pass_obj
 def cmd_delete(cloudscale, uuid, force):
-    resource = cloudscale.network
-    _delete(
-        resource=resource,
+    cloudscale.cmd_delete(
         uuid=uuid,
-        headers=headers,
         force=force,
     )
