@@ -1,29 +1,20 @@
 import click
-from . import _init, _list, _show, _create, _update, _delete
-
-headers = ['display_name', 'id', 'tags']
 
 @click.group()
-@click.option('--api-token', '-a', envvar='CLOUDSCALE_API_TOKEN', help="API token.")
-@click.option('--profile', '-p', help="Profile used in config file.")
-@click.option('--verbose', '-v', is_flag=True, help='Enables verbose mode.')
 @click.pass_context
-def objects_user(ctx, profile, api_token, verbose):
-    _init(
-        ctx=ctx,
-        api_token=api_token,
-        profile=profile,
-        verbose=verbose,
-    )
+def objects_user(ctx):
+    ctx.obj.cloud_resource_name = "objects_user"
+    ctx.obj.headers = [
+        'display_name',
+        'id',
+        'tags',
+    ]
 
 @click.option('--filter-tag')
 @objects_user.command("list")
 @click.pass_obj
 def cmd_list(cloudscale, filter_tag):
-    resource = cloudscale.objects_user
-    _list(
-        resource=resource,
-        headers=headers,
+    cloudscale.cmd_list(
         filter_tag=filter_tag,
     )
 
@@ -31,9 +22,7 @@ def cmd_list(cloudscale, filter_tag):
 @objects_user.command("show")
 @click.pass_obj
 def cmd_show(cloudscale, uuid):
-    resource = cloudscale.objects_user
-    _show(
-        resource=resource,
+    cloudscale.cmd_show(
         uuid=uuid,
     )
 
@@ -42,9 +31,7 @@ def cmd_show(cloudscale, uuid):
 @objects_user.command("create")
 @click.pass_obj
 def cmd_create(cloudscale, display_name, tags):
-    resource = cloudscale.objects_user
-    _create(
-        resource=resource,
+    cloudscale.cmd_create(
         display_name=display_name,
         tags=tags
     )
@@ -57,9 +44,7 @@ def cmd_create(cloudscale, display_name, tags):
 @objects_user.command("update")
 @click.pass_obj
 def cmd_update(cloudscale, uuid, display_name, tags, clear_tags, clear_all_tags):
-    resource = cloudscale.objects_user
-    _update(
-        resource=resource,
+    cloudscale.cmd_update(
         uuid=uuid,
         tags=tags,
         clear_tags=clear_tags,
@@ -72,10 +57,7 @@ def cmd_update(cloudscale, uuid, display_name, tags, clear_tags, clear_all_tags)
 @objects_user.command("delete")
 @click.pass_obj
 def cmd_delete(cloudscale, uuid, force):
-    resource = cloudscale.objects_user
-    _delete(
-        resource=resource,
+    cloudscale.cmd_delete(
         uuid=uuid,
-        headers=headers,
         force=force,
     )
