@@ -1,42 +1,44 @@
 import click
-from . import _init, _list, _show, _create, _update, _delete, _act
-
-headers = ['name', 'image', 'flavor', 'zone', 'tags', 'server_groups', 'uuid', 'status']
+import uuid
 
 @click.group()
-@click.option('--api-token', '-a', envvar='CLOUDSCALE_API_TOKEN', help="API token.")
-@click.option('--profile', '-p', help="Profile used in config file.")
-@click.option('--verbose', '-v', is_flag=True, help='Enables verbose mode.')
 @click.pass_context
-def server(ctx, profile, api_token, verbose):
-    _init(
-        ctx=ctx,
-        api_token=api_token,
-        profile=profile,
-        verbose=verbose,
-    )
+def server(ctx):
+    ctx.obj.cloud_resource_name = "server"
+    ctx.obj.headers = [
+        'name',
+        'image',
+        'flavor',
+        'zone',
+        'tags',
+        'server_groups',
+        'uuid',
+        'status',
+    ]
 
 @click.option('--filter-tag')
+@click.option('--filter-json')
+@click.option('--action', type=click.Choice(['start', 'stop', 'reboot']))
+@click.option('--delete', is_flag=True)
 @server.command("list")
 @click.pass_obj
-def cmd_list(cloudscale, filter_tag):
-    resource = cloudscale.server
-    _list(
-        resource=resource,
-        headers=headers,
+def cmd_list(cloudscale, filter_tag, filter_json, action, delete):
+    cloudscale.cmd_list(
         filter_tag=filter_tag,
+        filter_json=filter_json,
+        action=action,
+        delete=delete,
     )
 
 @click.argument('uuid', required=True)
 @server.command("show")
 @click.pass_obj
 def cmd_show(cloudscale, uuid):
-    resource = cloudscale.server
-    _show(
-        resource=resource,
+    cloudscale.cmd_show(
         uuid=uuid,
     )
 
+@click.option('--desired-amount', type=click.IntRange(1, 10), default=1, show_default=True)
 @click.option('--name', required=True)
 @click.option('--flavor', required=True)
 @click.option('--image', required=True)
@@ -71,26 +73,52 @@ def cmd_create(
     server_groups,
     user_data,
     tags,
+    desired_amount,
 ):
-    resource = cloudscale.server
-    _create(
-        resource=resource,
-        name=name,
-        flavor=flavor,
-        image=image,
-        zone=zone,
-        volume_size=volume_size,
-        volumes=volumes or None,
-        interfaces=interfaces or None,
-        ssh_keys=ssh_keys or None,
-        password=password,
-        use_public_network=use_public_network,
-        use_private_network=use_private_network,
-        use_ipv6=use_ipv6,
-        server_groups=server_groups or None,
-        user_data=user_data,
-        tags=tags,
-    )
+    if desired_amount > 1:
+        servers_created = list()
+
+        while len(servers_created) < desired_amount:
+            suffix = str(uuid.uuid4()).split('-')[0]
+            server_name =  click.prompt('Server name:', default=f"{name}-{suffix}")
+            s = cloudscale.cmd_create(
+                silent=True,
+                name=server_name,
+                flavor=flavor,
+                image=image,
+                zone=zone,
+                volume_size=volume_size,
+                volumes=volumes or None,
+                interfaces=interfaces or None,
+                ssh_keys=ssh_keys or None,
+                password=password,
+                use_public_network=use_public_network,
+                use_private_network=use_private_network,
+                use_ipv6=use_ipv6,
+                server_groups=server_groups or None,
+                user_data=user_data,
+                tags=tags,
+            )
+            servers_created.append(s)
+        click.echo(cloudscale._format_output(servers_created))
+    else:
+        cloudscale.cmd_create(
+            name=name,
+            flavor=flavor,
+            image=image,
+            zone=zone,
+            volume_size=volume_size,
+            volumes=volumes or None,
+            interfaces=interfaces or None,
+            ssh_keys=ssh_keys or None,
+            password=password,
+            use_public_network=use_public_network,
+            use_private_network=use_private_network,
+            use_ipv6=use_ipv6,
+            server_groups=server_groups or None,
+            user_data=user_data,
+            tags=tags,
+        )
 
 @click.argument('uuid', required=True)
 @click.option('--name')
@@ -102,16 +130,14 @@ def cmd_create(
 @server.command("update")
 @click.pass_obj
 def cmd_update(cloudscale, uuid, name, flavor, interfaces, tags, clear_tags, clear_all_tags):
-    resource = cloudscale.server
-    _update(
-        resource=resource,
+    cloudscale.cmd_update(
         uuid=uuid,
         tags=tags,
         clear_tags=clear_tags,
         clear_all_tags=clear_all_tags,
         name=name,
         flavor=flavor,
-        interfaces=interfaces,
+        interfaces=interfaces or None,
     )
 
 @click.argument('uuid', required=True)
@@ -119,11 +145,8 @@ def cmd_update(cloudscale, uuid, name, flavor, interfaces, tags, clear_tags, cle
 @server.command("delete")
 @click.pass_obj
 def cmd_delete(cloudscale, uuid, force):
-    resource = cloudscale.server
-    _delete(
-        resource=resource,
+    cloudscale.cmd_delete(
         uuid=uuid,
-        headers=headers,
         force=force,
     )
 
@@ -131,9 +154,7 @@ def cmd_delete(cloudscale, uuid, force):
 @server.command("start")
 @click.pass_obj
 def cmd_start(cloudscale, uuid):
-    resource = cloudscale.server
-    _act(
-        resource=resource,
+    cloudscale.cmd_act(
         action="start",
         uuid=uuid,
     )
@@ -142,9 +163,7 @@ def cmd_start(cloudscale, uuid):
 @server.command("stop")
 @click.pass_obj
 def cmd_stop(cloudscale, uuid):
-    resource = cloudscale.server
-    _act(
-        resource=resource,
+    cloudscale.cmd_act(
         action="stop",
         uuid=uuid,
     )
@@ -153,9 +172,7 @@ def cmd_stop(cloudscale, uuid):
 @server.command("reboot")
 @click.pass_obj
 def cmd_reboot(cloudscale, uuid):
-    resource = cloudscale.server
-    _act(
-        resource=resource,
+    cloudscale.cmd_act(
         action="reboot",
         uuid=uuid,
     )
