@@ -1,29 +1,22 @@
 import click
-from . import _init, _list, _show, _create, _update, _delete
-
-headers = ['name', 'type', 'servers', 'tags', 'uuid']
 
 @click.group()
-@click.option('--api-token', '-a', envvar='CLOUDSCALE_API_TOKEN', help="API token.")
-@click.option('--profile', '-p', help="Profile used in config file.")
-@click.option('--verbose', '-v', is_flag=True, help='Enables verbose mode.')
 @click.pass_context
-def server_group(ctx, profile, api_token, verbose):
-    _init(
-        ctx=ctx,
-        api_token=api_token,
-        profile=profile,
-        verbose=verbose,
-    )
+def server_group(ctx):
+    ctx.obj.cloud_resource_name = "server_group"
+    ctx.obj.headers = [
+        'name',
+        'type',
+        'servers',
+        'tags',
+        'uuid',
+    ]
 
 @click.option('--filter-tag')
 @server_group.command("list")
 @click.pass_obj
 def cmd_list(cloudscale, filter_tag):
-    resource = cloudscale.server_group
-    _list(
-        resource=resource,
-        headers=headers,
+    cloudscale.cmd_list(
         filter_tag=filter_tag,
     )
 
@@ -31,9 +24,7 @@ def cmd_list(cloudscale, filter_tag):
 @server_group.command("show")
 @click.pass_obj
 def cmd_show(cloudscale, uuid):
-    resource = cloudscale.server_group
-    _show(
-        resource=resource,
+    cloudscale.cmd_show(
         uuid=uuid,
     )
 
@@ -43,9 +34,7 @@ def cmd_show(cloudscale, uuid):
 @server_group.command("create")
 @click.pass_obj
 def cmd_create(cloudscale, name, group_type, tags):
-    resource = cloudscale.server_group
-    _create(
-        resource=resource,
+    cloudscale.cmd_create(
         name=name,
         group_type=group_type,
         tags=tags,
@@ -59,9 +48,7 @@ def cmd_create(cloudscale, name, group_type, tags):
 @server_group.command("update")
 @click.pass_obj
 def cmd_update(cloudscale, uuid, name, tags, clear_tags, clear_all_tags):
-    resource = cloudscale.server_group
-    _update(
-        resource=resource,
+    cloudscale.cmd_update(
         uuid=uuid,
         tags=tags,
         clear_tags=clear_tags,
@@ -74,10 +61,7 @@ def cmd_update(cloudscale, uuid, name, tags, clear_tags, clear_all_tags):
 @server_group.command("delete")
 @click.pass_obj
 def cmd_delete(cloudscale, uuid, force):
-    resource = cloudscale.server_group
-    _delete(
-        resource=resource,
+    cloudscale.cmd_delete(
         uuid=uuid,
-        headers=headers,
         force=force,
     )
