@@ -1,40 +1,32 @@
 import click
-from . import _init, _list, _show, _create, _update, _delete
-
-headers = ['name', 'type', 'size_gb', 'zone', 'tags', 'server_uuids', 'uuid']
 
 @click.group()
-@click.option('--api-token', '-a', envvar='CLOUDSCALE_API_TOKEN', help="API token.")
-@click.option('--profile', '-p', envvar='CLOUDSCALE_PROFILE', help="Profile used in config file.")
-@click.option('--verbose', '-v', is_flag=True, help='Enables verbose mode.')
 @click.pass_context
-def volume(ctx, profile, api_token, verbose):
-    _init(
-        ctx=ctx,
-        api_token=api_token,
-        profile=profile,
-        verbose=verbose,
-    )
+def volume(ctx):
+    ctx.obj.cloud_resource_name = "volume"
+    ctx.obj.headers = [
+        'name',
+        'type',
+        'size_gb',
+        'zone',
+        'tags',
+        'server_uuids',
+        'uuid',
+    ]
 
 @click.option('--filter-tag')
 @volume.command("list")
 @click.pass_obj
 def cmd_list(cloudscale, filter_tag):
-    resource = cloudscale.volume
-    _list(
-        resource=resource,
-        headers=headers,
+    cloudscale.cmd_list(
         filter_tag=filter_tag,
     )
 
-
 @click.argument('uuid', required=True)
 @volume.command("show")
 @click.pass_obj
 def cmd_show(cloudscale, uuid):
-    resource = cloudscale.volume
-    _show(
-        resource=resource,
+    cloudscale.cmd_show(
         uuid=uuid,
     )
 
@@ -47,9 +39,7 @@ def cmd_show(cloudscale, uuid):
 @volume.command("create")
 @click.pass_obj
 def cmd_create(cloudscale, name, server_uuids, size_gb, volume_type, zone, tags):
-    resource = cloudscale.volume
-    _create(
-        resource=resource,
+    cloudscale.cmd_create(
         name=name,
         server_uuids=server_uuids,
         size_gb=size_gb,
@@ -68,9 +58,7 @@ def cmd_create(cloudscale, name, server_uuids, size_gb, volume_type, zone, tags)
 @volume.command("update")
 @click.pass_obj
 def cmd_update(cloudscale, uuid, name, server_uuids, size_gb, tags, clear_tags, clear_all_tags):
-    resource = cloudscale.volume
-    _update(
-        resource=resource,
+    cloudscale.cmd_update(
         uuid=uuid,
         tags=tags,
         clear_tags=clear_tags,
@@ -85,10 +73,7 @@ def cmd_update(cloudscale, uuid, name, server_uuids, size_gb, tags, clear_tags,
 @volume.command("delete")
 @click.pass_obj
 def cmd_delete(cloudscale, uuid, force):
-    resource = cloudscale.volume
-    _delete(
-        resource=resource,
+    cloudscale.cmd_delete(
         uuid=uuid,
-        headers=headers,
         force=force,
     )
